OGBWikiKG2
==========

.. currentmodule:: pykeen.datasets

.. autoclass:: OGBWikiKG2
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~OGBWikiKG2.name

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
